-- version: 1.7
--[[
只有下列必要的地方改成Unicode字型，其他地方不受影響
1. 聊天視窗，Chat Bubble
2. 寵物名
3. 公會名單Rank與Note
4. 公會會員詳細資料視窗Rank與Note
5. 公會視窗Message of the Day
6. Guild Information視窗
7. CharacterFrame Rank
8. InspectFrame Rank
9. Raid Warning Frame
10. CTRA Warning Frame
11. Macro輸入
12. LibSharedMedia-3.0 support
--]]
-- code inspired by CLEARFONT BY KIRKBURN

UnicodeFontFrame = CreateFrame("Frame", "UnicodeFontFrame")

UNICODEFONT = "Interface\\AddOns\\UnicodeFont\\wqy-zenhei.ttf"

-- LibSharedMedia-3.0 support
local SharedMedia = LibStub("LibSharedMedia-3.0")
SharedMedia:Register("font", "UnicodeFont", UNICODEFONT)

-- Font scale - e.g. if you want all fonts at 80% scale, change '1' to '0.8'
local SCALE = 1

local function CanSetFont(object) 
	return (type(object)=="table" and object.SetFont and object.IsObjectType and not object:IsObjectType("SimpleHTML"))
end

function UnicodeFontFrame:ApplySystemFonts()
	-- Chat bubbles
	STANDARD_TEXT_FONT = UNICODEFONT;
	-- Names above people's heads
	UNIT_NAME_FONT = UNICODEFONT;
	NAMEPLATE_FONT = UNICODEFONT;
	
	-- guild panel
	for i = 1, 13, 1 do
		if (CanSetFont(getglobal("GuildFrameGuildStatusButton"..i.."Rank"))) then 		getglobal("GuildFrameGuildStatusButton"..i.."Rank"):SetFont(UNICODEFONT, 12 * SCALE); end
		if (CanSetFont(getglobal("GuildFrameGuildStatusButton"..i.."Note"))) then 		getglobal("GuildFrameGuildStatusButton"..i.."Note"):SetFont(UNICODEFONT, 12 * SCALE); end
	end
	if (CanSetFont(GuildFrameNotesText)) then GuildFrameNotesText:SetFont(UNICODEFONT, 12 * SCALE); end
	if (CanSetFont(GuildMemberDetailRankText)) then	GuildMemberDetailRankText:SetFont(UNICODEFONT, 12 * SCALE); end
	if (CanSetFont(PersonalNoteText)) then PersonalNoteText:SetFont(UNICODEFONT, 13 * SCALE); end --GameFontHighlight
	if (CanSetFont(OfficerNoteText)) then OfficerNoteText:SetFont(UNICODEFONT, 13 * SCALE); end --GameFontHighlight
	if (CanSetFont(GuildInfoEditBox)) then GuildInfoEditBox:SetFont(UNICODEFONT, 13 * SCALE); end
	
	-- paper doll frame
	if (CanSetFont(CharacterGuildText)) then CharacterGuildText:SetFont(UNICODEFONT, 11 * SCALE); end
	if (CanSetFont(PetNameText)) then PetNameText:SetFont(UNICODEFONT, 13 * SCALE); end --GameFontHighlight
	
	-- inspect frame
	if (CanSetFont(InspectGuildText)) then InspectGuildText:SetFont(UNICODEFONT, 11 * SCALE); end
	
	-- chat font
	if (CanSetFont(ChatFontNormal)) then ChatFontNormal:SetFont(UNICODEFONT, 14 * SCALE); end
	
	-- raid warning
	if (CanSetFont(RaidWarningFrame)) then RaidWarningFrame:SetFont(UNICODEFONT, 20 * SCALE); end
	if (CanSetFont(RaidWarningFrameSlot1)) then RaidWarningFrameSlot1:SetFont(UNICODEFONT, 20 * SCALE); end
	if (CanSetFont(RaidWarningFrameSlot2)) then RaidWarningFrameSlot2:SetFont(UNICODEFONT, 20 * SCALE); end
	
	-- ctra warning
	if (CanSetFont(CT_RA_WarningFrame)) then CT_RA_WarningFrame:SetFont(UNICODEFONT, 17 * SCALE); end
	
	-- macros
	if (CanSetFont(MacroFrameText)) then MacroFrameText:SetFont(UNICODEFONT, 12 * SCALE); end
	
	-- mail
	if (CanSetFont(MailFont_Large)) then MailFont_Large:SetFont(UNICODEFONT, 15 * SCALE); end
	if (CanSetFont(OpenMailSubject)) then OpenMailSubject:SetFont(UNICODEFONT, 12 * SCALE); end
	
	
	--[[
	if (CanSetFont(SystemFont)) then 			SystemFont:SetFont(UNICODEFONT, 17 * SCALE); end
	if (CanSetFont(GameFontNormal)) then 		GameFontNormal:SetFont(UNICODEFONT, 13 * SCALE); end
	if (CanSetFont(GameFontHighlight)) then 	GameFontHighlight:SetFont(UNICODEFONT, 13 * SCALE); end
	if (CanSetFont(GameFontDisable)) then 		SystemFont:SetFont(UNICODEFONT, 13 * SCALE); end
	if (CanSetFont(GameFontDisable)) then 		GameFontDisable:SetTextColor(0.6, 0.6, 0.6); end
	if (CanSetFont(GameFontGreen)) then 		GameFontGreen:SetFont(UNICODEFONT, 13 * SCALE); end
	if (CanSetFont(GameFontRed)) then 			GameFontRed:SetFont(UNICODEFONT, 13 * SCALE); end
	if (CanSetFont(GameFontWhite)) then 		GameFontWhite:SetFont(UNICODEFONT, 13 * SCALE); end
	if (CanSetFont(GameFontBlack)) then 		GameFontBlack:SetFont(UNICODEFONT, 13 * SCALE); end
	if (CanSetFont(GameFontNormalSmall)) then 		GameFontNormalSmall:SetFont(UNICODEFONT, 12 * SCALE); end
	if (CanSetFont(GameFontDisableSmall)) then 		GameFontDisableSmall:SetFont(UNICODEFONT, 12 * SCALE); end
	if (CanSetFont(GameFontDisableSmall)) then 		GameFontDisableSmall:SetTextColor(0.6, 0.6, 0.6); end
	if (CanSetFont(GameFontDarkGraySmall)) then 		GameFontDarkGraySmall:SetFont(UNICODEFONT, 12 * SCALE); end
	if (CanSetFont(GameFontDarkGraySmall)) then 		GameFontDarkGraySmall:SetTextColor(0.4, 0.4, 0.4); end
	if (CanSetFont(GameFontGreenSmall)) then 		GameFontGreenSmall:SetFont(UNICODEFONT, 12 * SCALE); end
	if (CanSetFont(GameFontRedSmall)) then 			GameFontRedSmall:SetFont(UNICODEFONT, 12 * SCALE); end
	if (CanSetFont(GameFontHighlightSmall)) then 	GameFontHighlightSmall:SetFont(UNICODEFONT, 12 * SCALE); end
	if (CanSetFont(GameFontHighlightSmallOutline)) then GameFontHighlightSmallOutline:SetFont(UNICODEFONT, 12 * SCALE, "OUTLINE"); end
	if (CanSetFont(GameFontNormalLarge)) then 		GameFontNormalLarge:SetFont(UNICODEFONT, 17 * SCALE); end
	if (CanSetFont(GameFontHighlightLarge)) then 	GameFontHighlightLarge:SetFont(UNICODEFONT, 17 * SCALE); end
	if (CanSetFont(GameFontDisableLarge)) then 		GameFontDisableLarge:SetFont(UNICODEFONT, 17 * SCALE); end
	if (CanSetFont(GameFontDisableLarge)) then 		GameFontDisableLarge:SetTextColor(0.6, 0.6, 0.6); end
	if (CanSetFont(GameFontGreenLarge)) then 		GameFontGreenLarge:SetFont(UNICODEFONT, 17 * SCALE); end
	if (CanSetFont(GameFontRedLarge)) then 			GameFontRedLarge:SetFont(UNICODEFONT, 17 * SCALE); end
	if (CanSetFont(GameFontNormalHuge)) then 		GameFontNormalHuge:SetFont(UNICODEFONT, 21 * SCALE); end
	if (CanSetFont(ChatFontNormal)) then 			ChatFontNormal:SetFont(UNICODEFONT, 14 * SCALE); end
	--]]
end

UnicodeFontFrame:SetScript("OnEvent",
	function() 
		if (event == "ADDON_LOADED") then
			UnicodeFontFrame:ApplySystemFonts()
		end
	end);
	
UnicodeFontFrame:RegisterEvent("ADDON_LOADED");

UnicodeFontFrame:ApplySystemFonts()
